[Piglit] [PATCH 3/7] astc_sliced_3d: Add an assert for texture depth

Anuj Phogat anuj.phogat at gmail.com
Mon Aug 1 22:16:16 UTC 2016


Also update the comment reflecting the texture depth.

Cc: Nanley Chery <nanley.g.chery at intel.com>
Signed-off-by: Anuj Phogat <anuj.phogat at gmail.com>
---
 .../khr_compressed_astc-sliced-3d-miptree.c                    | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/tests/spec/khr_texture_compression_astc/khr_compressed_astc-sliced-3d-miptree.c b/tests/spec/khr_texture_compression_astc/khr_compressed_astc-sliced-3d-miptree.c
index 29ecc8b..d833bac 100644
--- a/tests/spec/khr_texture_compression_astc/khr_compressed_astc-sliced-3d-miptree.c
+++ b/tests/spec/khr_texture_compression_astc/khr_compressed_astc-sliced-3d-miptree.c
@@ -27,10 +27,11 @@
  *
  * The files under compressed/SLICED3D/{hdr, ldrl, ldrs} contain full miptrees,
  * in the GL_*_ASTC_* formats, of a sliced 3D texture of waffles and fruit [1].
  * The base level size was shrunken to 160x106 pixels. The files under the
  * decompressed/SLICED3D/{hdr, ldrl, ldrs} directory contain the same miptree in
  * GL_RGBA format. Each miplevel was obtained by decompressing the corresponding
  * ASTC texture with astcenc [2].
  *
  * This test draws miplevels of the compressed textures in a space-efficient
  * manner. It does the same when drawing the decompressed texture on the right.
@@ -150,6 +151,7 @@ load_texture(const char *dir1, const char *dir2,
 	assert(info->target == GL_TEXTURE_3D);
 	assert(info->pixel_width == LEVEL0_WIDTH);
 	assert(info->pixel_height == LEVEL0_HEIGHT);
+	assert(info->pixel_depth == LEVEL0_DEPTH);
 
 	*tex_name = 0;
 	ok = piglit_ktx_load_texture(ktx, tex_name, NULL);
@@ -27,10 +27,11 @@
  * The files under compressed/SLICED3D/{hdr, ldrl, ldrs} contain full miptrees,
  * in the GL_*_ASTC_* formats, of a sliced 3D texture of waffles and fruit [1].
- * The base level size was shrunken to 160x106 pixels. The files under the
- * decompressed/SLICED3D/{hdr, ldrl, ldrs} directory contain the same miptree in
- * GL_RGBA format. Each miplevel was obtained by decompressing the corresponding
- * ASTC texture with astcenc [2].
+ * The base level size was shrunken to 160x106 pixels and used to create a sliced
+ * 3D texture with depth=8.
+ * The files under the decompressed/SLICED3D/{hdr, ldrl, ldrs} directory contain
+ * the same miptree in GL_RGBA format. Each miplevel was obtained by decompressing
+ * the corresponding ASTC texture with astcenc [2].
  *
  * This test draws miplevels of the compressed textures in a space-efficient
-- 
2.5.5



More information about the Piglit mailing list